Struct UrlCleaner

pub struct UrlCleaner { /* private fields */ }
A UrlCleaner can remove tracking parameters from URLs.

This struct is relatively expensive to construct because it needs to parse the rules from JSON. It’s recommended to create one per application and reuse it.

Implementations

Source

impl UrlCleaner

pub fn from_rules_path(path: &Path) -> Result<Self, Error>

Available on crate feature std only.

Construct a UrlCleaner with rules from a path, which will be opened and read.

Errors

See Error

pub fn from_rules_file<R: Read>(reader: R) -> Result<Self, Error>

Available on crate feature std only.

Construct a UrlCleaner with rules from a reader, most often a File

Errors

See Error

pub fn from_rules_str(rules: &str) -> Result<Self, Error>

Errors

See Error

pub fn from_embedded_rules() -> Result<Self, Error>

Construct using the JSON embedded in this library. This may be outdated, but should provide a good baseline.

Errors

See Error

pub fn strip_referral_marketing(self, value: bool) -> Self

Configure whether you want to strip referral codes and similar parameters.

While they can be considered to be tracking, they are useful on occasion. The default is false, meaning these are kept.

pub fn clear_single_url_str<'a>( &self, url: &'a str, ) -> Result<Cow<'a, str>, Error>

Clean a single URL.

The argument is a string that is just a URL, with no text around.

The Cleaning may involve

    1. removing tracking parameters and/or,
    1. detecting redirections with the target url in a query parameters
Returns

a cleaned URL

Errors

If an error occurred. See the Error enum for possible reasons.

pub fn clear_single_url<'a>(&self, url: &'a Url) -> Result<Cow<'a, Url>, Error>

Clean a single URL.

The Cleaning may involve

    1. removing tracking parameters and/or,
    1. detecting redirections with the target url in a query parameters
Returns

a cleaned URL

Errors

If an error occurred. See the Error enum for possible reasons.